#!/bin/bash
# Name: check_mc.sh
# Description: Checks an entry in the Modbus cache file.
# Author: Andrew Meares
# Date: 6/5/2013
#
# $1 is cache file name
# $2 is Key Name
# $3, $4, and $5 are Integers
# $6 is cache timeout in seconds
# Returns Critical if V < $3
# Returns Warning if $3 <= V < $4
# Returns OK if $4 <= V < $5
# Returns Warning if $5 <= V < $6
# Returns Critical if V >= $6
# Returns Unknown (Error) if cache file is older than $7 seconds

# Options
READMODPATH=/usr/local/modcache/readmod.py
CACHEDIR=/usr/local/modcache

# Check cache status
S=`$READMODPATH --cachefile $CACHEDIR/$1 Status`
# Trim whitespace
S=`echo $S`

# Return Nagios Unknown (Error)
if [ "$S" != "Success" ]
then
	echo "Error: cache update failed."
	exit 3
fi

# Check cache timestamp
T1=`$READMODPATH --cachefile $CACHEDIR/$1 Time`
T2=`date +%s`
DT=`echo "($T2-$T1)/1" | bc`

# Return Nagios Unknown (Error)
if [ "$DT" -gt "$7" ]
then
	echo "Error: cache is out of date."
	exit 3
fi

# Check Value
V=`$READMODPATH --cachefile $CACHEDIR/$1 $2`

if [ "$V" -lt "$3" ]
then
	echo "Critical: $2 is critically low. | $2=$V"
	exit 2
fi

if [ "$V" -lt "$4" ]
then
	echo "Warning: $2 is low. | $2=$V"
	exit 1
fi

if [ "$V" -lt "$5" ]
then
	echo "OK: $2 is good. | $2=$V"
	exit 0
fi

if [ "$V" -lt "$6" ]
then
	echo "Warning: $2 is high. | $2=$V"
fi

if [ "$V" -ge "$6" ]
then
	echo "Critical: $2 is critically high. | $2=$V"
	exit 2
fi
