#!/bin/bash
# Name: check_mc.sh
# Description: Checks an entry in the Modbus cache file.
# Author: Andrew Meares
# Date: 6/5/2013
#
# $1 is cache file name
# $2 is Key Name
# $3 is bit number (0-15)
# $4 is expected value (1/0)
# Returns OK if bit is $4, or Critical if bit is not $4
# Returns Unknown (Error) if cache file is older than $5 seconds
# Returns Unknown (Error) if cache file status is not "Success"

# Options
READMODPATH=/usr/local/modcache/readmod.py
CACHEDIR=/usr/local/modcache


# Check cache status
S=`$READMODPATH --cachefile $CACHEDIR/$1 Status`
# Trim whitespace
S=`echo $S`

# Return Nagios Unknown (Error)
if [ "$S" != "Success" ]
then
	echo "Error: cache update failed."
	exit 3
fi

# Check cache timestamp
T1=`$READMODPATH --cachefile $CACHEDIR/$1 Time`
T2=`date +%s`
DT=`echo "($T2-$T1)/1" | bc`

# Return Nagios Unknown (Error)
if [ "$DT" -gt "$5" ]
then
	echo "Error: cache is out of date."
	exit 3
fi

# Check Value
V=`$READMODPATH --cachefile $CACHEDIR/$1 $2`
MV=$((2**$3))
if [ $(($V & $MV)) -eq $MV ]
then
	if [ $4 -eq 1 ]
	then
		echo "OK: $2 bit $3 is set."
		exit 0
	else
		echo "Critical: $2 bit $3 is set."
		exit 2
	fi
else
	if [ $4 -eq 1 ]
	then
		echo "Critical: $2 bit $3 is not set."
		exit 2
	else
		echo "OK: $2 bit $3 is not set."
		exit 0
	fi
fi
