#!/bin/bash
# Name: check_mc_perfdata.sh
# Description: Checks an entry in the Modbus cache file.
# Author: Andrew Meares
# Date: 6/5/2013
#
# $1 is cache file name
# $2 is Key Name
# $3 is cache timeout in seconds
# Returns OK for any values of the performance data (for logging only)
# Uses $4 scale value for perfdata (ie, $4=10 for tenth)
# The test values still have to be in the original units
# Returns Unknown (Error) if cache file is older than $3 seconds

# Options
READMODPATH=/usr/local/modcache/readmod.py
CACHEDIR=/usr/local/modcache

# Check cache status
S=`$READMODPATH --cachefile $CACHEDIR/$1 Status`
# Trim whitespace
S=`echo $S`

# Return Nagios Unknown (Error)
if [ "$S" != "Success" ]
then
	echo "Error: cache update failed."
	exit 3
fi

# Check cache timestamp
T1=`$READMODPATH --cachefile $CACHEDIR/$1 Time`
T2=`date +%s`
DT=`echo "($T2-$T1)/1" | bc`

# Return Nagios Unknown (Error)
if [ "$DT" -gt "$3" ]
then
	echo "Error: cache is out of date."
	exit 3
fi

# Check Value
V=`$READMODPATH --cachefile $CACHEDIR/$1 $2`
P=`echo "scale=1; $V/$4" | bc`

echo "OK: logging performance data. | $2=$P"
exit 0
