#!/usr/bin/python
#-------------------------------------------------------------------------------
# Name: readmod.py
# Author: Andrew Meares
# Date: 6/4/2013
# Description:
# 	Reads a list of registers from the cache file created by monmod.py.
#	Run ./readmod.py -h for command line help.
#
# tab = \t
#-------------------------------------------------------------------------------
import sys
import csv
import time
import argparse


#-------------------------------------------------------------------------------
# Settings
#-------------------------------------------------------------------------------
PROGRAM_DESCRIPTION = 'A utility for reading a Modbus cache.'
DEFAULT_PATH = 'cache.csv'
DEFAULT_KEY = 'Time'


#-------------------------------------------------------------------------------
# Command Line Arguments Class
#-------------------------------------------------------------------------------
class Arguments:
	def __init__(self):
		# setup the command line arguments
		self.parser = argparse.ArgumentParser(description=PROGRAM_DESCRIPTION)
		# add the arguments
		self.parser.add_argument('keys', metavar='K', type=str, nargs='+', help='Key names')
		self.parser.add_argument('-c', '--cachefile', help='Cache filename', type=str, default=DEFAULT_PATH)
		# parse the command line arguments
		self.args = self.parser.parse_args()
		
	def get(self):
		return self.args




#-------------------------------------------------------------------------------
# Main Program
#-------------------------------------------------------------------------------
cmdArgs = Arguments()
args = cmdArgs.get()

# This is my attempt to open a file with 3 retries.
# The technique is untested.
count = 0
result = False
while ((result == False) and (count < 3)):	
	try:
		# try to open the file
		ifile  = open(args.cachefile, "r")
	except Exception, e:
		# try again after sleeping for 1/3 second
		count = count + 1
		time.sleep(0.3)
		result = False
	else:
		result = True

if (result==False):
	print "Unable to open register file."
	exit(1)

# Create the reader
reader = csv.reader(ifile);

# Create a dictionary
dr = dict()
for row in reader:
	dr[row[0]]=row[1]

# Output to stdout
for k in args.keys:
	print dr[k],
	print "\t",
print ""

# Close the file
ifile.close()

